@@ -6,5 +6,5 @@ from .abstract import Abstract
 class Gene(Abstract):
   '''Webapp Gene class'''
   def __init__(self, cfg):
-    super().__init__(cfg)
+    super(Gene, self).__init__(cfg)
     self.endpoint += 'genes/'
